@@ -1,6 +1,7 @@
 import argparse
 from ..submission import upload_item_data
 from ..base import UsingCGAPKeysFile
+from ..utils import script_catch_errors
 
 
 EPILOG = __doc__
@@ -17,9 +18,14 @@ def main(simulated_args_for_testing=None):
     parser.add_argument('--uuid', '-u', help='uuid identifier', default=None)
     parser.add_argument('--server', '-s', help="an http or https address of the server to use", default=None)
     parser.add_argument('--env', '-e', help="a CGAP beanstalk environment name for the server to use", default=None)
+    parser.add_argument('--no_query', '-nq', action="store_true",
+                        help="suppress requests for user input", default=False)
     args = parser.parse_args(args=simulated_args_for_testing)
 
-    upload_item_data(item_filename=args.part_filename, uuid=args.uuid, server=args.server, env=args.env)
+    with script_catch_errors():
+
+        upload_item_data(item_filename=args.part_filename, uuid=args.uuid, server=args.server,
+                         env=args.env, no_query=args.no_query)
 
 
 if __name__ == '__main__':
